@@ -9,6 +9,7 @@ import (
 	"reflect"
 	"regexp"
 	"runtime"
+	"strings"
 	"time"
 
 	"dario.cat/mergo"
@@ -78,6 +79,7 @@ func (c *cfgBuild) RegexCompiled() ([]*regexp.Regexp, error) {
 type cfgLog struct {
 	AddTime  bool `toml:"time"`
 	MainOnly bool `toml:"main_only"`
+	Silent   bool `toml:"silent"`
 }
 
 type cfgColor struct {
@@ -186,7 +188,7 @@ func defaultPathConfig() (*Config, error) {
 	for _, name := range []string{dftTOML, dftConf} {
 		cfg, err := readConfByName(name)
 		if err == nil {
-			if name == dftConf {
+			if name == dftConf && !cfg.Log.Silent {
 				fmt.Println("`.air.conf` will be deprecated soon, recommend using `.air.toml`.")
 			}
 			return cfg, nil
@@ -237,6 +239,7 @@ func defaultConfig() Config {
 	log := cfgLog{
 		AddTime:  false,
 		MainOnly: false,
+		Silent:   false,
 	}
 	color := cfgColor{
 		Main:    "magenta",
@@ -305,9 +308,7 @@ func (c *Config) preprocess() error {
 	if c.TestDataDir == "" {
 		c.TestDataDir = "testdata"
 	}
-	if err != nil {
-		return err
-	}
+
 	ed := c.Build.ExcludeDir
 	for i := range ed {
 		ed[i] = cleanPath(ed[i])
@@ -328,6 +329,9 @@ func (c *Config) preprocess() error {
 	// CMD will not recognize relative path like ./tmp/server
 	c.Build.Bin, err = filepath.Abs(c.Build.Bin)
 
+	// Account for spaces in filepath
+	c.Build.Bin = fmt.Sprintf("%q", c.Build.Bin)
+
 	return err
 }
 
@@ -363,7 +367,8 @@ func (c *Config) killDelay() time.Duration {
 }
 
 func (c *Config) binPath() string {
-	return filepath.Join(c.Root, c.Build.Bin)
+	bin := strings.Trim(c.Build.Bin, "\"")
+	return fmt.Sprintf("%q", filepath.Join(c.Root, bin))
 }
 
 func (c *Config) tmpPath() string {
